function [row,col,mat,xu,yu,zu] = findcube_mdds3d(x,y,z,mx,my,mz)
%findcube_mdds3d -->  Determination of the unit cube containing 
%                     the 3D evaluation point chosen in the 
%                     Box-spline domain.
%
%<Synopsis>
%  [row,col,mat,xu,yu,zu] = findcube_mdds3d(x,y,z,mx,my,mz)
%
%<Description>
%  Determine in which unit cube of the trivariate Box-spline  
%  domain the evaluation point is contained.
%
%<Input Parameters>
%  x   --> first coordinate of the evaluation point
%   
%  y   --> second coordinate of the evaluation point
%  
%  z   --> third coordinate of the evaluation point
%   
%  mx  --> maximal value that the first coordinate of an 
%          arbitrary evaluation point could assume
%
%  my  --> maximal value that the second coordinate of an 
%          arbitrary evaluation point could assume
%
%  mz  --> maximal value that the third coordinate of an 
%          arbitrary evaluation point could assume
%
%<Output Parameters>
%  row --> row index that identifies the rows in the
%          B-net coefficients 3D-matrix containing
%          the six tetrahedral Bezier volumes 
%          defined in the specified cube region
%
%  col --> column index that identifies the columns in the
%          B-net coefficients 3D-matrix containing
%          the six tetrahedral Bezier volumes 
%          defined in the specified cube region
%
%  mat --> matrix index that identifies the matrices in the 
%          B-net coefficients 3D-matrix containing
%          the six tetrahedral Bezier volumes 
%          defined in the specified cube region
%
%  xu  --> value of the first coordinate (x) of the  
%          evaluation point mapped in [0,1]
%
%  yu  --> value of the second coordinate (y) of the 
%          evaluation point mapped in [0,1]
%
%  zu  --> value of the third coordinate (z) of the 
%          evaluation point mapped in [0,1] 

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

col=floor(x)+1;
xu=x-floor(x);
if x==mx
   col=col-1;
   xu=xu+1;
end
mat=floor(y)+1;
yu=y-floor(y);
if y==my
   mat=mat-1;
   yu=yu+1;
end
row=mz-floor(z);
zu=z-floor(z);
if z==mz
   row=row+1;
   zu=zu+1;
end