function c = integ_mdds(b)
%integ_mdds --> Computation of antidifferences (summations)
%               on the coefficients in the vector b.
%
%<Synopsis>
%  c = integ_mdds(b)
%
%<Description>
%  Both in bivariate and trivariate cases, the generation of the
%  mixed directions requires to compute antidifferences on the 
%  coefficients.
%
%<Input Parameters>
%  b --> vector with the coefficients to which apply antidifferences
%
%<Output Parameters>  
%  c --> vector whose coefficients have been obtained applying 
%        the summations procedure on b
%        (if b is a row vector, c is a row vector too;
%        if b is a column vector, c is a column vector too)

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

[rb,cb]=size(b);

s=max(rb,cb)+1;
c=zeros(1,s);
for i=2:s
    c(i)=c(i-1)+b(i-1);
end

if cb==1
   c=c(:);
end
